# lndocs: Lamin site generator

This is a command line tool. Install via:

```
pip install git+https://github.com/laminlabs/lndocs.git
```

And then build your documentation by calling the tool in the root of your project repository.

```
lndocs
```

The basis for this is largely Sphinx. More explanation to come.
